@@ -1,3 +1,3 @@
-from .trading212 import Trading212, Mode
 from .order import *
 from .position import Position
+from .trading212 import CFD, Equity, Trading212, Mode
